Security Advisories (2)
CPANSA-Mozilla-CA-2011-34

Google Chrome user alibo encountered an active "man in the middle" (MITM) attack on secure SSL connections to Google servers. The fraudulent certificate was mis-issued by DigiNotar, a Dutch Certificate Authority. DigiNotar has reported evidence that other fraudulent certificates were issued and in active use but the full extent of the compromise is not known.

CVE-2024-39689 (2024-06-11)

ECM GlobalTrust 2000 root certificates have been distrusted

NAME

Mozilla::CA - Mozilla's CA cert bundle in PEM format

SYNOPSIS

    use Mozilla::CA;
    use IO::Socket::SSL;

    my $client = IO::Socket::SSL->new(
        PeerHost => "www.example.com:https",
	SSL_ca_file => Mozilla::CA::SSL_ca_file(),
    );

DESCRIPTION

Mozilla::CA provides a copy of Mozilla's bundle of Certificate Authority certificates in a form that can be consumed by modules and libraries based on OpenSSL.

The module provide a single function:

SSL_ca_file()

Returns the absolute path to the Mozilla's CA cert bundle PEM file.

SEE ALSO

http://curl.haxx.se/docs/caextract.html